PeriodListError

Enum PeriodListError 

pub enum PeriodListError {
    InvalidInterval {
        index: usize,
    },
    Unsorted {
        index: usize,
    },
    Overlapping {
        index: usize,
    },
}
Error indicating a period list violates sorted/non-overlapping invariants.

Variants



InvalidInterval

An interval at the given index has start > end.

Fields

index: usize

Index of the malformed interval.



Unsorted

The interval at the given index has a start time earlier than its predecessor.

Fields

index: usize

Index of the out-of-order interval.



Overlapping

The interval at the given index overlaps with its predecessor.

Fields

index: usize

Index of the overlapping interval.