pub struct JDE;Expand description
Julian Ephemeris Day — dynamic Julian day used by ephemerides.
Numerically this is an absolute Julian day on the TT axis in this crate. It is a semantic label for ephemeris formulas, not a UT→TT conversion.