TCG

Struct TCG 

pub struct TCG;
Geocentric Coordinate Time — the coordinate time for the GCRS.

TCG is the proper time experienced by a clock at the geocenter, free from the gravitational time dilation of the Earth’s potential.

The defining relation (IAU 2000 Resolution B1.9) is:

dTT / dTCG = 1 − L_G

where L_G = 6.969 290 134 × 10⁻¹⁰ is an IAU defining constant. Integrating:

TT = TCG − L_G × (JD_TCG − T₀)

with T₀ = 2 443 144.500 372 5 (JD of 1977 January 1.0 TAI in the TCG scale).

References

  • IAU 2000 Resolution B1.9
  • IERS Conventions (2010), 1.2