pub enum PeriodListError {
InvalidInterval {
index: usize,
},
Unsorted {
index: usize,
},
Overlapping {
index: usize,
},
}Expand description
Error indicating a period list violates sorted/non-overlapping invariants.
Variants
InvalidInterval
An interval at the given index has start > end.
Unsorted
The interval at the given index has a start time earlier than its predecessor.
Overlapping
The interval at the given index overlaps with its predecessor.